@@ -4,8 +4,8 @@ from django.template import loader, Context
 from . import InvoiceFormatter
 
 
-class BootstrapHTMLFormatter(InvoiceFormatter):
-    template_name = 'invoicing/formatters/bootstrap.html'
+class HTMLFormatter(InvoiceFormatter):
+    template_name = 'invoicing/formatters/html.html'
 
     def get_data(self):
         return {
@@ -13,9 +13,18 @@ class BootstrapHTMLFormatter(InvoiceFormatter):
             "INVOICING_DATE_FORMAT_TAG": "d.m.Y"  # TODO: move to settings
         }
 
-    def get_response(self):
+    def get_response(self, context={}):
         template = loader.get_template(self.template_name)
         data = self.get_data()
-        context = Context(data)
-        response_data = template.render(context)
+        data.update(context)
+
+        try:
+            response_data = template.render(Context(data))
+        except TypeError:
+            response_data = template.render(data)
+
         return HttpResponse(response_data)
+
+
+class BootstrapHTMLFormatter(HTMLFormatter):
+    template_name = 'invoicing/formatters/bootstrap.html'
